@@ -24,7 +24,7 @@ Version: 0.1.2
 """
 import os
 import platform
-
+from 
 def get_os_info():
     """
     Get Operating System Information
@@ -420,18 +420,21 @@ def get_total_size(folder_path: str) -> int:
             item_path = os.path.join(folder_path, item)
             total_size += get_size(item_path)
     return total_size
+
 def get_files(directory):
     file_list = []
     for root,dirs,files in os.walk(directory):
         for file in files:
             file_list.append(os.path.join(root,file))
     return file_list
+
 def get_folders(directory):
     directory_list = []
     for root,dirs,files in os.walk(directory):
         for folder in dirs:
             directory_list.append(os.path.join(root,folder))
     return directory_list
+
 def break_down_find_existing(path):
     slash = get_slash()
     test_path=''
@@ -442,13 +445,113 @@ def break_down_find_existing(path):
             return found_path
         found_path = test_path
     return found_path
+
 def get_directory_items(directory):
     if not os.path.isdir(directory):
         return []
     return os.listdir(directory)
+
+def get_directory_files(directory):
+    if not os.path.isdir(directory):
+        return []
+    return get_files(directory)
+
 def get_all_item_paths(directory):
     directory_items = get_directory_items(directory)
     item_paths = [os.path.join(directory,item) for item in directory_items if item]
     return item_paths
 
-        
+def get_all_file_paths(directory):
+    item_paths = get_directory_files(directory) 
+    return item_paths
+
+def get_directory(directory):
+    if not os.path.isdir(directory):
+        os.makedirs(directory,exist_ok=True)
+    return directory
+
+def create_directory(directory,path):
+    directory = os.path.join(directory,path)
+    return get_directory(directory)
+
+
+def initialize_file(directory,basename):
+    directory = get_directory(directory)
+    file_path = create_directory(directory,basename)
+    return get_file_path(file_path)
+
+def join_path(directory,basename):
+    file_path = os.path.join(directory,basename)
+    return file_path
+
+def is_last_itter(i,*itters):
+    itter_len = len(itters)
+    if i+1 == itter_len:
+        return True
+    return False
+
+def path_join(*paths,isfile=False):
+    final_path = os.path.join(*paths)
+    paths_len = len(paths)
+    for i,path in enumerate(paths):
+        if i == 0:
+            final_path = paths
+        else:
+            final_path = os.path.join(final_path,path)
+        if isfile and is_last_itter(i,*itters):
+            break
+        os.makedirs(final_path,exist_ok=True)      
+    return final_path
+
+def is_file(*paths):
+    item_path = os.path.join(*paths)
+    return os.path.isfile(item_path)
+
+def is_dir(*paths):
+    item_path = os.path.join(*paths)
+    return os.path.isdir(item_path)
+
+def is_path(*paths):
+    item_path = os.path.join(*paths)
+    return item_path if os.path.exists(item_path) else None
+
+def get_all_directories(directory):
+    dir_list = os.listdir(directory)
+    directory_list = [item for item in dir_list if is_dir(directory,item)]
+    return directory_list
+
+def get_all_files(directory):
+    dir_list = os.listdir(directory)
+    file_list = [item for item in dir_list if is_file(directory,item)]
+    return file_list
+
+def get_all_items(directory):
+    dir_list = os.listdir(directory)
+    file_list = [item for item in dir_list if is_path(directory,item)]
+    return file_list
+
+def collate_text_docs(directory):
+    directory_list = get_dirlist(directory)
+    return [get_content(directory,item) for item in directory_list if is_file(directory,item)]
+
+def get_dirlist(directory):
+    path = get_directory(directory)
+    if not path:
+        return path
+    dir_list=[]
+    if is_dir(path):
+        dir_list = os.listdir(path)
+    elif is_file(path):
+        dir_list = [os.path.basename(path)]
+    return dir_list
+def get_content(*paths):
+    item_path = os.path.join(*paths)
+    if os.path.isfile(item_path):
+        try:
+            content = read_from_file(item_path)
+            return content
+        except:
+            pass
+    return None
+def is_directory_in_paths(path,directory):
+    return directory in path 
