@@ -58,7 +58,8 @@ Version: 0.1.2
 """
 import os
 from typing import Union
-from .path_utils import get_all_item_paths
+from .path_utils import get_all_item_paths,get_files
+from .list_utils import make_list
 def get_all_key_values(keys=None,dict_obj=None):
     keys = keys or []
     dict_obj = dict_obj or {}
@@ -69,7 +70,7 @@ def get_all_key_values(keys=None,dict_obj=None):
             new_dict_obj[key]=values
     return new_dict_obj
 def get_media_types(types=None):
-    types = types or []
+    types = make_list(types) or []
     media_types = {
         'image': {'.jpg', '.jpeg', '.png', '.gif', '.bmp', '.tiff', '.webp', '.svg'},
         'video': {'.mp4', '.avi', '.mov', '.wmv', '.flv', '.mkv', '.webm'},
@@ -91,13 +92,20 @@ def confirm_type(file_path,media_types=None):
              return typ
     
 def get_all_types(types=None,directory=None):
-    types = types or []
     if not directory or not os.path.isdir(directory):
         return []
     item_paths = get_all_item_paths(directory)
     media_types = get_media_types(types=types)
     item_paths = [item_path for item_path in item_paths if confirm_type(item_path,media_types=media_types)]
-    return item_paths    
+    return item_paths
+def get_all_file_types(types=None,directory=None):
+    if not directory or not os.path.isdir(directory):
+        return []
+    item_paths = get_files(directory)
+    media_types = get_media_types(types=types)
+    item_paths = [item_path for item_path in item_paths if confirm_type(item_path,media_types=media_types)]
+    return item_paths
+
 def is_iterable(obj:any):
     try:
         iterator=iter(obj)
@@ -480,19 +488,7 @@ def dict_check_conversion(obj:any) -> Union[dict,any]:
         return json.loads(obj)
     
     return obj
-def make_list(obj:any) -> list:
-    """
-    Converts the input object to a list. If the object is already a list, it is returned as is.
-    
-    Args:
-        obj: The object to convert.
-        
-    Returns:
-        list: The object as a list.
-    """
-    if isinstance(obj, list):
-        return obj
-    return [obj]
+
     
 def make_list_lower(ls: list) -> list:
     """
@@ -688,14 +684,7 @@ def if_default_return_obj(obj:any,default:any=None,default_compare:any=None):
         return obj
     return default
 
-def convert_and_normalize_values(values):
-    for value in values:
-        if isinstance(value, str):
-            yield value.lower()
-        elif isinstance(value, (int, float)):
-            yield value
-        else:
-            yield str(value).lower()
+
             
 def convert_to_number(value):
     value_str = str(value)
